# Taxref

[![Anaconda-Server Badge](https://anaconda.org/cosmoloj/taxref/badges/version.svg)](https://anaconda.org/cosmoloj/taxref)
[![Anaconda-Server Badge](https://anaconda.org/cosmoloj/taxref/badges/latest_release_date.svg)](https://anaconda.org/cosmoloj/taxref)
[![Anaconda-Server Badge](https://anaconda.org/cosmoloj/taxref/badges/latest_release_relative_date.svg)](https://anaconda.org/cosmoloj/taxref)
[![Anaconda-Server Badge](https://anaconda.org/cosmoloj/taxref/badges/platforms.svg)](https://anaconda.org/cosmoloj/taxref)
[![Anaconda-Server Badge](https://anaconda.org/cosmoloj/taxref/badges/license.svg)](https://anaconda.org/cosmoloj/taxref)

[![PyPI repository Badge](https://badge.fury.io/py/taxref.svg)](https://badge.fury.io/py/taxref)

## Dépendances

```bash
conda install pandas
```

## Variables d'environnement

```
BIOLOJ=/path/to/.bioloj/root/
```

## Arborescence dans `.bioloj`

* `taxref/TAXREF_INPN_v11` : fichiers taxref v11